@@ -1,11 +1,10 @@
-#!/usr/bin/env perl
 package Mouse::Role;
 use strict;
 use warnings;
 use base 'Exporter';
 
 use Carp 'confess';
-use Mouse::Util 'blessed';
+use Scalar::Util 'blessed';
 
 use Mouse::Meta::Role;
 
@@ -49,17 +48,38 @@ sub has {
 
 sub extends  { confess "Roles do not support 'extends'" }
 
-sub with     { confess "Mouse::Role does not currently support 'with'" }
+sub with     {
+    my $meta = Mouse::Meta::Role->initialize(caller);
+    my $role  = shift;
+    my $args  = shift || {};
+    confess "Mouse::Role only supports 'with' on individual roles at a time" if @_ || !ref $args;
 
-sub requires { confess "Mouse::Role does not currently support 'requires'" }
+    Mouse::load_class($role);
+    $role->meta->apply($meta, %$args);
+}
+
+sub requires {
+    my $meta = Mouse::Meta::Role->initialize(caller);
+    Carp::croak "Must specify at least one method" unless @_;
+    $meta->add_required_methods(@_);
+}
 
 sub excludes { confess "Mouse::Role does not currently support 'excludes'" }
 
 sub import {
+    my $class = shift;
+
     strict->import;
     warnings->import;
 
     my $caller = caller;
+
+    # we should never export to main
+    if ($caller eq 'main') {
+        warn qq{$class does not export its sugar to the 'main' package.\n};
+        return;
+    }
+
     my $meta = Mouse::Meta::Role->initialize(caller);
 
     no strict 'refs';
